/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>

QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>

// module include
#include "pyside2_qtwebenginewidgets_python.h"

// main header
#include "qwebenginehistoryitem_wrapper.h"

// inner classes

// Extra includes
#include <QtCore/qdatetime.h>
#include <QtCore/qurl.h>
#include <QtWebEngineWidgets/qwebenginehistory.h>


#include <cctype>
#include <cstring>



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineHistoryItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineHistoryItem >()))
        return -1;

    ::QWebEngineHistoryItem *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebEngineHistoryItem", 1, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineHistoryItem::QWebEngineHistoryItem(QWebEngineHistoryItem)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QWebEngineHistoryItem(QWebEngineHistoryItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEngineHistoryItem_Init_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWebEngineHistoryItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QWebEngineHistoryItem(QWebEngineHistoryItem)
            cptr = new ::QWebEngineHistoryItem(*cppArg0);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineHistoryItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebEngineHistoryItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWebEngineHistoryItem_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem");
        return -1;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_iconUrl(PyObject *self)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // iconUrl()const
            QUrl cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->iconUrl();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_isValid(PyObject *self)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_lastVisited(PyObject *self)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // lastVisited()const
            QDateTime cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->lastVisited();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QDATETIME_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_originalUrl(PyObject *self)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // originalUrl()const
            QUrl cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->originalUrl();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_swap(PyObject *self, PyObject *pyArg)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineHistoryItem::swap(QWebEngineHistoryItem&)
    if ((pyArg != Py_None && (pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX]), (pyArg))))) {
        overloadId = 0; // swap(QWebEngineHistoryItem&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEngineHistoryItemFunc_swap_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineHistoryItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // swap(QWebEngineHistoryItem&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEngineHistoryItemFunc_swap_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.swap");
        return {};
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_title(PyObject *self)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // title()const
            QString cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->title();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_url(PyObject *self)
{
    ::QWebEngineHistoryItem *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItem___copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QWebEngineHistoryItem &cppSelf =  *reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX]), &cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QWebEngineHistoryItem_methods[] = {
    {"iconUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_iconUrl), METH_NOARGS},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_isValid), METH_NOARGS},
    {"lastVisited", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_lastVisited), METH_NOARGS},
    {"originalUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_originalUrl), METH_NOARGS},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_swap), METH_O},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_title), METH_NOARGS},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_url), METH_NOARGS},

    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItem___copy__), METH_NOARGS},
    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineHistoryItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QWebEngineHistoryItem_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QWebEngineHistoryItem_Type = nullptr;
static SbkObjectType *Sbk_QWebEngineHistoryItem_TypeF(void)
{
    return _Sbk_QWebEngineHistoryItem_Type;
}

static PyType_Slot Sbk_QWebEngineHistoryItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineHistoryItem_spec = {
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineHistoryItem_slots
};

} //extern "C"


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineHistoryItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QWebEngineHistoryItem_TypeF())))
        return QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineHistoryItem_PTR_CppToPython_QWebEngineHistoryItem(const void *cppIn) {
    auto pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::QWebEngineHistoryItem *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
     }
    PyObject *result = Shiboken::Object::newObject(Sbk_QWebEngineHistoryItem_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QWebEngineHistoryItem_COPY_CppToPython_QWebEngineHistoryItem(const void *cppIn) {
    return Shiboken::Object::newObject(Sbk_QWebEngineHistoryItem_TypeF(), new ::QWebEngineHistoryItem(*reinterpret_cast<const ::QWebEngineHistoryItem *>(cppIn)), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEngineHistoryItem *>(cppOut) = *reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX], reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QWebEngineHistoryItem_TypeF())))
        return QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWebEngineHistoryItem_SignatureStrings[] = {
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem(other:PySide2.QtWebEngineWidgets.QWebEngineHistoryItem)",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.iconUrl()->PySide2.QtCore.QUrl",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.isValid()->bool",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.lastVisited()->PySide2.QtCore.QDateTime",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.originalUrl()->PySide2.QtCore.QUrl",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.swap(other:PySide2.QtWebEngineWidgets.QWebEngineHistoryItem)",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.title()->QString",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.url()->PySide2.QtCore.QUrl",
    "PySide2.QtWebEngineWidgets.QWebEngineHistoryItem.__copy__()",
    nullptr}; // Sentinel

void init_QWebEngineHistoryItem(PyObject *module)
{
    _Sbk_QWebEngineHistoryItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineHistoryItem",
        "QWebEngineHistoryItem",
        &Sbk_QWebEngineHistoryItem_spec,
        QWebEngineHistoryItem_SignatureStrings,
        &Shiboken::callCppDestructor< ::QWebEngineHistoryItem >,
        0,
        0,
        0    );
    
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QWebEngineHistoryItem_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QWebEngineHistoryItem_TypeF(),
        QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR,
        is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR_Convertible,
        QWebEngineHistoryItem_PTR_CppToPython_QWebEngineHistoryItem,
        QWebEngineHistoryItem_COPY_CppToPython_QWebEngineHistoryItem);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineHistoryItem");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineHistoryItem*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineHistoryItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineHistoryItem).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY,
        is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY_Convertible);


}
